@@ -1,6 +1,7 @@
 from __future__ import absolute_import
 
-from unittest import TestCase, main
+import logging
+from unittest import TestCase, main, skipIf
 
 from lark import Lark, Tree, Transformer
 from lark.lexer import Lexer, Token
@@ -11,6 +12,10 @@ try:
 except ImportError:
     from io import BytesIO as StringIO
 
+try:
+    import regex
+except ImportError:
+    regex = None
 
 class MockFile(StringIO):
     def close(self):
@@ -140,6 +145,25 @@ class TestCache(TestCase):
         res = parser.parse("ab")
         self.assertEqual(res, Tree('startab', [Tree('expr', ['a', 'b'])]))
 
+    @skipIf(regex is None, "'regex' lib not installed")
+    def test_recursive_pattern(self):
+        g = """
+        start: recursive+
+        recursive: /\w{3}\d{3}(?R)?/
+        """
+
+        assert len(self.mock_fs.files) == 0
+        Lark(g, parser="lalr", regex=True, cache=True)
+        assert len(self.mock_fs.files) == 1
+
+        with self.assertLogs("lark", level="ERROR") as cm:
+            Lark(g, parser='lalr', regex=True, cache=True)
+            assert len(self.mock_fs.files) == 1
+            # need to add an error log, because 'self.assertNoLogs' was added in Python 3.10
+            logging.getLogger('lark').error("dummy message")
+        # should only have the dummy log
+        self.assertCountEqual(cm.output, ["ERROR:lark:dummy message"])
+
         
 
 
